# Graph Embeddings

Graph Embeddings are a way to learn a low dimensional representation of a graph. Through a graph embedding a graph can be represented in low dimensional form, while preserving graph information. This low-dimensional representation can then be used for training classic machine learning algorithms that would otherwise make no use of the graph information.

The Graph Embeddings used by PHOTON Graph are static graph embeddings, based on the [gem python package](https://github.com/palash1992/GEM).


## GraphEmbeddingHOPE
::: photonai_graph.GraphEmbedding.GraphEmbeddingHOPE.__init__
    rendering:
        show_root_toc_entry: False

## GraphEmbeddingLaplacianEigenmaps
::: photonai_graph.GraphEmbedding.GraphEmbeddingLaplacianEigenmaps.__init__
    rendering:
        show_root_toc_entry: False

## GraphEmbeddingLocallyLinearEmbedding
::: photonai_graph.GraphEmbedding.GraphEmbeddingLocallyLinearEmbedding.__init__
    rendering:
        show_root_toc_entry: False
